@@ -1,8 +1,21 @@
-# -*- coding: utf-8 -*-
-'''
-:author: Davide Mancusi
-:date: 2019-09-19
-'''
+# Copyright 2019-2021 Davide Mancusi, Martin Maurey, Jonathan Faustin
+#
+# This file is part of t4_geom_convert.
+#
+# t4_geom_convert is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the Free
+# Software Foundation, either version 3 of the License, or (at your option) any
+# later version.
+#
+# t4_geom_convert is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+# more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# t4_geom_convert.  If not, see <https://www.gnu.org/licenses/>.
+#
+# vim: set fileencoding=utf-8 :
 
 from math import sqrt, cos, sin, isclose
 
@@ -11,7 +24,7 @@ def scal(v1, v2):
     '''Yields the scalar product of `v1` and `v2`.'''
     a1, b1, c1 = v1
     a2, b2, c2 = v2
-    result = a1*a2 + b1*b2 + c1*c2
+    result = a1 * a2 + b1 * b2 + c1 * c2
     return float(result)
 
 
@@ -19,7 +32,7 @@ def vect(v1, v2):
     '''Yields the vector product of `v1` and `v2`.'''
     x1, y1, z1 = v1
     x2, y2, z2 = v2
-    result = (y1*z2-z1*y2, x2*z1-x1*z2, x1*y2-y1*x2)
+    result = (y1 * z2 - z1 * y2, x2 * z1 - x1 * z2, x1 * y2 - y1 * x2)
     return result
 
 
@@ -36,7 +49,7 @@ def mixed(v1, v2, v3):
 def rescale(a, v1):
     '''Return `v1` multiplied by a scalar `a`, as a new vector.'''
     x1, y1, z1 = v1
-    return (a*x1, a*y1, a*z1)
+    return (a * x1, a * y1, a * z1)
 
 
 def vsum(*args):
@@ -55,12 +68,12 @@ def vdiff(v1, v2):
     '''Return the vector difference of `v1` and `v2` (`v1-v2`).'''
     x1, y1, z1 = v1
     x2, y2, z2 = v2
-    return (x1-x2, y1-y2, z1-z2)
+    return (x1 - x2, y1 - y2, z1 - z2)
 
 
 def renorm(vec, norm=1.):
     '''Return a new vector parallel to `vec` whose norm is equal to `norm`.'''
-    return rescale(norm/mag(vec), vec)
+    return rescale(norm / mag(vec), vec)
 
 
 def mag2(vec):
@@ -105,7 +118,7 @@ def rotate(vec, axis, angle):
     sangle = sin(angle)
     term1 = rescale(cangle, vec)
     term2 = rescale(sangle, vect(axis, vec))
-    term3 = rescale((1 - cangle)*scal(axis, vec), axis)
+    term3 = rescale((1 - cangle) * scal(axis, vec), axis)
     return vsum(term1, term2, term3)
 
 
@@ -169,6 +182,7 @@ def planeParamsFromPoints(pt1, pt2, pt3):
                      'points are collinear or almost so: {}, {}, {}'
                      .format(pt1, pt2, pt3))
 
+
 def planeParamsFromNormalAndPoint(normal, point):
     '''Return the MCNP-style parameters of the plane having the given normal
     and passing through the given points.'''
@@ -246,7 +260,7 @@ def projectPointOnPlane(point, plane, direction):
     True
     '''
     pl_pt, normal = plane
-    dist = scal(vdiff(pl_pt, point), normal)/scal(direction, normal)
+    dist = scal(vdiff(pl_pt, point), normal) / scal(direction, normal)
     return vsum(point, rescale(dist, direction))
 
 
@@ -297,4 +311,4 @@ def matrix_rows(matrix):
     [[1, 2, 3], [4, 5, 6], [7, 8, 9]]
     '''
     assert len(matrix) == 9
-    return [matrix[3*i:3*i+3] for i in range(3)]
+    return [matrix[3 * i:3 * i + 3] for i in range(3)]
